@@ -23,10 +23,10 @@ import tarfile
 from tempfile import TemporaryDirectory
 from typing import TYPE_CHECKING, Dict, Iterable, List, Optional, Sequence, Union
 
-from docker import APIClient, tls
-from docker.constants import DEFAULT_TIMEOUT_SECONDS
-from docker.errors import APIError
-from docker.types import Mount
+from docker import APIClient, tls  # type: ignore[attr-defined]
+from docker.constants import DEFAULT_TIMEOUT_SECONDS  # type: ignore[attr-defined]
+from docker.errors import APIError  # type: ignore[attr-defined]
+from docker.types import DeviceRequest, Mount  # type: ignore[attr-defined]
 
 from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
@@ -136,6 +136,7 @@ class DockerOperator(BaseOperator):
         file before manually shutting down the image. Useful for cases where users want a pickle serialized
         output that is not posted to logs
     :param retrieve_output_path: path for output file that will be retrieved and passed to xcom
+    :param device_requests: Expose host resources such as GPUs to the container.
     """
 
     template_fields: Sequence[str] = ('image', 'command', 'environment', 'container_name')
@@ -183,6 +184,7 @@ class DockerOperator(BaseOperator):
         retrieve_output: bool = False,
         retrieve_output_path: Optional[str] = None,
         timeout: int = DEFAULT_TIMEOUT_SECONDS,
+        device_requests: Optional[List[DeviceRequest]] = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -227,6 +229,7 @@ class DockerOperator(BaseOperator):
         self.retrieve_output = retrieve_output
         self.retrieve_output_path = retrieve_output_path
         self.timeout = timeout
+        self.device_requests = device_requests
 
     def get_hook(self) -> DockerHook:
         """
@@ -290,6 +293,7 @@ class DockerOperator(BaseOperator):
                 cap_add=self.cap_add,
                 extra_hosts=self.extra_hosts,
                 privileged=self.privileged,
+                device_requests=self.device_requests,
             ),
             image=self.image,
             user=self.user,
